

set -ex



clang-14 --version
test ! -f "$PREFIX/bin/clang"
test ! -f "$PREFIX/bin/clang-cl"
test ! -f "$PREFIX/bin/clang-cpp"
test ! -f "$PREFIX/lib/libclang-cpp.so"
test -f "$PREFIX/lib/libclang-cpp.so.14"
test -f "$PREFIX/lib/clang/14.0.6/include/stdatomic.h"
exit 0
